library ieee;
use ieee.std_logic_1164.all;

entity xchk is
	port(
		ce_n:		out	std_logic;	-- Flash RAM chip-enable
		
		V_tdo:	in	std_logic;	-- TDO from Virtex FPGA
		V_rd:		out	std_logic;	-- RD pin of xchecker port used for TDO

		-- Virtex FPGA pins
		V_done:	in	std_logic;	-- input from Virtex done pin
		V_m:		out	std_logic_vector(2 downto 0);	-- Virtex config mode pins

		bar:		out	std_logic_vector(1 downto 0)	-- LED bargraph
	);
end xchk;


architecture arch of xchk is
	constant LO: std_logic := '0';
	constant HI: std_logic := '1';
	constant SLAVE_SERIAL_MODE: std_logic_vector(2 downto 0) := "111";
begin

	-- connect Virtex configuration pins
	V_m <= SLAVE_SERIAL_MODE;	-- set Virtex config mode pins into JTAG mode

	-- disable the Flash RAM so its outputs cannot interfere with the JTAG pins
	ce_n <= HI;
	
	-- loop Virtex TDO output pin over to RD pin on the Xchecker interface
	-- Note: V_tdo is also connected to Virtex pin 163 and V_rd is
	-- connected to Virtex pin 133, so keep these two Virtex pins
	-- tristated if you are using the XChecker JTAG interface to the Virtex.
	V_rd <= V_tdo;

	-- display status of Virtex done pin on the bargraph LED
	bar(0) <= V_done;
	
end arch;

